@@ -13,6 +13,8 @@
 
 #' checkEmpty
 #'
+#' Checks if a df is actually a single NA, or has no columns
+#'
 #' @param df a data frame
 #' @return None. Stops if empty.
 #' @examples
@@ -24,12 +26,39 @@ checkEmpty <- function(df) {
   # So this logic ensures we proceed for large data frames without running the is.na
   # step
   
-  
-  if(nrow(df)>1) {
-    return()
-  } else if (nrow(df) ==0 || is.na(df)) {
+  if(is.null(ncol(df)) || is.na(ncol(df)) || ncol(df)==0) {
+    stop("ERROR : One oe more dataframes have no coumns")
+  }
+}
+
+
+
+#' CheckNA 
+#' 
+#' Checks a data frame is NA - if so, stops
+#' 
+#' @param df A (probable) dataframe
+#' 
+#' @return Nothing. Errors is df is NA
+
+checkNA <- function(df) {
+  if(isSingleNA(df)) {
     stop('ERROR : One or more dataframes are empty')
   }
 }
 
 
+#' isSingleNA
+#' 
+#' Boolean function - T if x is a single NA. False otherwise.
+#' 
+#' @param x literally anything
+#' 
+#' @return boolean
+isSingleNA <- function(x) {
+  if(is.vector(x) && length(x) == 1 && is.na(x)) {
+    TRUE
+  } else {
+    FALSE
+  }
+}
